@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright (C) 2003, 2004 Christian Persch
  *  
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-encodings.h,v 1.5 2003/12/18 15:58:00 chpe Exp $
+ *  $Id: ephy-encodings.h,v 1.10 2005/01/08 19:41:46 chpe Exp $
  */
 
 #ifndef EPHY_ENCODINGS_H
@@ -35,7 +35,9 @@ G_BEGIN_DECLS
 #define EPHY_IS_ENCODINGS_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_ENCODINGS))
 #define EPHY_ENCODINGS_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_ENCODINGS, EphyEncodingsClass))
 
-typedef struct EphyEncodingsPrivate EphyEncodingsPrivate;
+typedef struct _EphyEncodings		EphyEncodings;
+typedef struct _EphyEncodingsPrivate	EphyEncodingsPrivate;
+typedef struct _EphyEncodingsClass	EphyEncodingsClass;
 
 typedef enum
 {
@@ -65,43 +67,6 @@ typedef enum
 }
 EphyLanguageGroup;
 
-/* from htmlparser/nsIParser.h */
-/* note: the value order defines the priority */
-typedef enum
-{
-	EMBED_ENCODING_UNINITIALISED		= 0,
-	EMBED_ENCODING_WEAK_DOCTYPE_DEFAULT	= 1,
-	EMBED_ENCODING_USER_DEFAULT		= 2,
-	EMBED_ENCODING_DOCTYPE_DEFAULT		= 3,
-	EMBED_ENCODING_CACHE			= 4,
-	EMBED_ENCODING_PARENT_FRAME		= 5,
-	EMBED_ENCODING_BOOKMARKS		= 6,
-	EMBED_ENCODING_AUTODETECTION		= 7,
-	EMBED_ENCODING_HINT_PREV_DOC		= 8,
-	EMBED_ENCODING_META_TAG			= 9,
-	EMBED_ENCODING_BOM			= 10,
-	EMBED_ENCODING_CHANNEL			= 11,
-	EMBED_ENCODING_PARENT_FORCED		= 12,
-	EMBED_ENCODING_USER_FORCED		= 13,
-	EMBED_ENCODING_OTHER_COMPONENT		= 14,
-	EMBED_ENCODING_PREV_LOADING		= 15
-}
-EphyEncodingSource;
-
-typedef struct
-{
-	char *encoding;
-	char *default_encoding;
-	char *hint_encoding;
-	char *prev_doc_encoding;
-	char *forced_encoding;
-	char *parent_encoding;
-	EphyEncodingSource encoding_source;
-	EphyEncodingSource hint_encoding_source;
-	EphyEncodingSource parent_encoding_source;
-}
-EphyEncodingInfo;
-
 enum
 {
 	EPHY_NODE_ENCODING_PROP_TITLE = 1,
@@ -112,25 +77,26 @@ enum
 	EPHY_NODE_ENCODING_PROP_IS_AUTODETECTOR = 6
 };
 
-typedef struct
+struct _EphyEncodings
 {
 	GObject parent;
 
 	/*< private >*/
 	EphyEncodingsPrivate *priv;
-} EphyEncodings;
+};
 
-typedef struct
+struct _EphyEncodingsClass
 {
 	GObjectClass parent_class;
-} EphyEncodingsClass;
+};
 
 GType		 ephy_encodings_get_type        (void);
 
 EphyEncodings	*ephy_encodings_new             (void);
 
 EphyNode	*ephy_encodings_get_node	(EphyEncodings *encodings,
-						 const char *code);
+						 const char *code,
+						 gboolean add_if_not_found);
 
 GList		*ephy_encodings_get_encodings	(EphyEncodings *encodings,
 						 EphyLanguageGroup group_mask);
@@ -144,10 +110,6 @@ void		 ephy_encodings_add_recent	(EphyEncodings *encodings,
 
 GList		*ephy_encodings_get_recent	(EphyEncodings *encodings);
 
-void		 ephy_encoding_info_free	(EphyEncodingInfo *info);
-
-gboolean	 ephy_encoding_info_is_automatic (EphyEncodingInfo *info);
-
 G_END_DECLS
 
 #endif
