@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSDialogs.cpp,v 1.20 2004/10/10 16:03:53 marco Exp $
+ *  $Id: GtkNSSDialogs.cpp,v 1.27 2005/01/15 20:08:06 chpe Exp $
  */
 
 /*
@@ -28,11 +28,7 @@
 
 #include "mozilla-config.h"
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
-
-#ifdef HAVE_MOZILLA_PSM
 
 #include "EphyUtils.h"
 
@@ -49,7 +45,9 @@
 #include <nsICRLInfo.h>
 #include <nsISimpleEnumerator.h>
 #include <nsIArray.h>
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 
 #include <gconf/gconf-client.h>
 #include <gtk/gtkdialog.h>
@@ -73,7 +71,7 @@
 #include <gtk/gtktextbuffer.h>
 #include <gtk/gtktextview.h>
 #include <gtk/gtkprogressbar.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <time.h>
 
 #include "GtkNSSDialogs.h"
@@ -209,16 +207,21 @@ display_cert_warning_box (nsIInterfaceRequestor *ctx,
 	int res;
 
 	nsCOMPtr<nsIDOMWindow> parent = do_GetInterface (ctx);
-	GtkWidget *gparent = EphyUtils::FindGtkParent (parent);
+	GtkWindow *gparent = GTK_WINDOW (EphyUtils::FindGtkParent (parent));
 
         g_return_val_if_fail (markup_text, GTK_RESPONSE_CANCEL);
         g_return_val_if_fail (!checkbox_text || checkbox_value, GTK_RESPONSE_CANCEL);
 	
-	dialog = gtk_dialog_new_with_buttons ("",
-					      gparent ? GTK_WINDOW (gparent) : NULL,
+	dialog = gtk_dialog_new_with_buttons ("", gparent,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      NULL);
+	if (gparent)
+	{
+		gtk_window_group_add_window (ephy_gui_ensure_window_group (gparent),
+					     GTK_WINDOW (dialog));
+	}
 
+	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
 	higgy_setup_dialog (GTK_DIALOG (dialog), 
@@ -285,7 +288,7 @@ GtkNSSDialogs::ConfirmMismatchDomain (nsIInterfaceRequestor *ctx,
                                       const nsACString &targetURL,
                                       nsIX509Cert *cert, PRBool *_retval)
 {
-	char *ttTargetUrl, *ttCommonName, *first, *second, *msg;
+	char *first, *second, *msg;
 	int res;
 
 	nsEmbedString commonName;
@@ -295,20 +298,17 @@ GtkNSSDialogs::ConfirmMismatchDomain (nsIInterfaceRequestor *ctx,
 	NS_UTF16ToCString (commonName,
 			   NS_CSTRING_ENCODING_UTF8, cCommonName);
 
- 	ttTargetUrl = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
-                                               nsEmbedCString(targetURL).get());
+	nsEmbedCString cTargetUrl (targetURL);
 
-	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", cCommonName.get());
+        first = g_markup_printf_escaped (_("The site \"%s\" returned security information for "
+					   "\"%s\". It is possible that someone is intercepting "
+					   "your communication to obtain your confidential "
+					   "information."),
+					 cTargetUrl.get(), cCommonName.get());
 
-        first = g_strdup_printf (_("The site %s returned security information for "
-				   "%s. It is possible that someone is intercepting "
-				   "your communication to obtain your confidential "
-				   "information."),
-				 ttTargetUrl, ttCommonName);
-
-        second = g_strdup_printf (_("You should only accept the security information if you "
-                                    "trust %s and %s."),
-                                  ttTargetUrl, ttCommonName);
+        second = g_markup_printf_escaped (_("You should only accept the security information if you "
+					    "trust \"%s\" and \"%s\"."),
+					  cTargetUrl.get(), cCommonName.get());
 	
 	msg = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s\n\n%s",
 			       _("Accept incorrect security information?"),
@@ -316,8 +316,6 @@ GtkNSSDialogs::ConfirmMismatchDomain (nsIInterfaceRequestor *ctx,
  
 	res = display_cert_warning_box (ctx, cert, msg, NULL, NULL, NULL);
  
-	g_free (ttTargetUrl);
-	g_free (ttCommonName);
         g_free (second);
         g_free (first);
         g_free (msg);
@@ -333,7 +331,7 @@ GtkNSSDialogs::ConfirmUnknownIssuer (nsIInterfaceRequestor *ctx,
                                      PRBool *_retval)
 {
 	gboolean accept_perm = FALSE;
-	char *ttCommonName, *secondary, *tertiary, *msg;
+	char *secondary, *tertiary, *msg;
 	int res;
 
 	nsEmbedString commonName;
@@ -343,18 +341,16 @@ GtkNSSDialogs::ConfirmUnknownIssuer (nsIInterfaceRequestor *ctx,
 	NS_UTF16ToCString (commonName,
 			   NS_CSTRING_ENCODING_UTF8, cCommonName);
 
-	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", cCommonName.get());
-
-	secondary = g_strdup_printf
-		           (_("Your browser was unable to trust %s. "
+	secondary = g_markup_printf_escaped
+		           (_("It was not possible to automatically trust \"%s\". "
 			      "It is possible that someone is intercepting your "
 			      "communication to obtain your confidential information."),
-			      ttCommonName);
+			      cCommonName.get());
 
-        tertiary = g_strdup_printf
+        tertiary = g_markup_printf_escaped
 		           (_("You should only connect to the site if you are certain "
-			      "you are connected to %s."),
-			    ttCommonName);
+			      "you are connected to \"%s\"."),
+			    cCommonName.get());
 
 	msg = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s\n\n%s",
 			       _("Connect to untrusted site?"),
@@ -363,7 +359,6 @@ GtkNSSDialogs::ConfirmUnknownIssuer (nsIInterfaceRequestor *ctx,
 	res = display_cert_warning_box (ctx, cert, msg, 
  					_("_Don't show this message again for this site"),
  					&accept_perm, _("Co_nnect"));
-	g_free (ttCommonName);
         g_free (tertiary);
         g_free (secondary);
         g_free (msg);
@@ -406,7 +401,7 @@ GtkNSSDialogs::ConfirmCertExpired (nsIInterfaceRequestor *ctx,
 	char formattedDate[128];
 	char *fdate;
 	const char *primary, *text;
-	char *ttCommonName, *secondary, *msg;
+	char *secondary, *msg;
 
 	*_retval = PR_FALSE;
 	
@@ -423,14 +418,14 @@ GtkNSSDialogs::ConfirmCertExpired (nsIInterfaceRequestor *ctx,
 	if (LL_CMP(now, >, notAfter))
 	{
 		primary = _("Accept expired security information?");
-		text    = _("The security information for %s "
+		text    = _("The security information for \"%s\" "
 			    "expired on %s.");
 		timeToUse = notAfter;
 	} 
 	else
 	{
 		primary = _("Accept not yet valid security information?");
-		text    = _("The security information for %s isn't valid until %s.");
+		text    = _("The security information for \"%s\" isn't valid until %s.");
 		timeToUse = notBefore;
 	}
 	
@@ -450,9 +445,7 @@ GtkNSSDialogs::ConfirmCertExpired (nsIInterfaceRequestor *ctx,
 		  localtime_r (&t, &tm));
 	fdate = g_locale_to_utf8 (formattedDate, -1, NULL, NULL, NULL);
 
-	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", cCommonName.get());
-
-	secondary = g_strdup_printf (text, ttCommonName, fdate);
+	secondary = g_markup_printf_escaped (text, cCommonName.get(), fdate);
 
 	msg = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s\n\n%s",
 			       primary, secondary, 
@@ -463,7 +456,6 @@ GtkNSSDialogs::ConfirmCertExpired (nsIInterfaceRequestor *ctx,
 	g_free (fdate);
 	g_free (msg);
 	g_free (secondary);
-	g_free (ttCommonName);
 
 	*_retval = (res == GTK_RESPONSE_ACCEPT);
 	
@@ -477,7 +469,7 @@ GtkNSSDialogs::NotifyCrlNextupdate (nsIInterfaceRequestor *ctx,
 				    const nsACString & targetURL, nsIX509Cert *cert)
 {
 	GtkWidget *dialog, *label;
-	char *ttCommonName, *ttTargetUrl, *msg, *primary, *secondary;
+	char *msg, *primary, *secondary;
 
 	nsCOMPtr<nsIDOMWindow> parent = do_GetInterface (ctx);
 	GtkWidget *gparent = EphyUtils::FindGtkParent (parent);
@@ -501,17 +493,14 @@ GtkNSSDialogs::NotifyCrlNextupdate (nsIInterfaceRequestor *ctx,
 	NS_UTF16ToCString (commonName,
 			   NS_CSTRING_ENCODING_UTF8, cCommonName);
 
-	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", cCommonName.get());
+	nsEmbedCString cTargetUrl (targetURL);
 
-	ttTargetUrl = g_markup_printf_escaped ("\"<tt>%s</tt>\"",
-				               nsEmbedCString(targetURL).get());
+	primary = g_markup_printf_escaped (_("Cannot establish connection to \"%s\"."),
+					   cTargetUrl.get());
 
-	primary = g_strdup_printf (_("Cannot establish connection to %s."),
-				   ttTargetUrl);
-
-	secondary = g_strdup_printf (_("The certificate revocation list (CRL) from %s "
-				       "needs to be updated."),
-				     ttCommonName);
+	secondary = g_markup_printf_escaped (_("The certificate revocation list (CRL) from \"%s\" "
+					       "needs to be updated."),
+					     cCommonName.get());
 	msg = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s\n\n%s",
 			       primary, secondary,
 			       _("Please ask your system administrator for assistance."));
@@ -521,8 +510,6 @@ GtkNSSDialogs::NotifyCrlNextupdate (nsIInterfaceRequestor *ctx,
 	g_free (primary);
 	g_free (secondary);
 	g_free (msg);
-	g_free (ttCommonName);
-	g_free (ttTargetUrl);
 
 	gtk_widget_show_all (dialog);
 
@@ -542,13 +529,12 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 {
 	GtkWidget *dialog, *label, *content_vbox, *vbox;
 	GtkWidget *check_ssl, *check_software;
-	char *ttCommonName, *msg, *tertiary;
+	char *msg, *tertiary;
 
 	nsCOMPtr<nsIDOMWindow> parent = do_GetInterface (ctx);
-	GtkWidget *gparent = EphyUtils::FindGtkParent (parent);
+	GtkWindow *gparent = GTK_WINDOW (EphyUtils::FindGtkParent (parent));
 
-	dialog = gtk_dialog_new_with_buttons ("",
-					      GTK_WINDOW (gparent),
+	dialog = gtk_dialog_new_with_buttons ("", gparent,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      _("_View Certificate"),
 					      NSSDIALOG_RESPONSE_VIEW_CERT,
@@ -556,6 +542,12 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 					      _("_Trust CA"),	GTK_RESPONSE_ACCEPT,
 					      NULL);
 
+	if (gparent)
+	{
+		gtk_window_group_add_window (ephy_gui_ensure_window_group (gparent),
+					     GTK_WINDOW (dialog));
+	}
+
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
 	higgy_setup_dialog (GTK_DIALOG (dialog), GTK_STOCK_DIALOG_WARNING,
@@ -569,10 +561,7 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 	NS_UTF16ToCString (commonName,
 			   NS_CSTRING_ENCODING_UTF8, cCommonName);
 
-	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"",  cCommonName.get());
-
-	tertiary = g_strdup_printf (_("Trust %s to identify:"), ttCommonName);
-	g_free (ttCommonName);
+	tertiary = g_markup_printf_escaped (_("Trust \"%s\" to identify:"), cCommonName.get());
 
 	msg = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s\n\n%s",
 			       _("Trust new Certificate Authority?"),
@@ -644,15 +633,20 @@ GtkNSSDialogs::NotifyCACertExists (nsIInterfaceRequestor *ctx)
 	char * msg;
 
 	nsCOMPtr<nsIDOMWindow> parent = do_GetInterface (ctx);
-	GtkWidget *gparent = EphyUtils::FindGtkParent (parent);
+	GtkWindow *gparent = GTK_WINDOW (EphyUtils::FindGtkParent (parent));
 
-	dialog = gtk_dialog_new_with_buttons ("",
-					      GTK_WINDOW (gparent),
+	dialog = gtk_dialog_new_with_buttons ("", gparent,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_OK,
 					      GTK_RESPONSE_OK,
 					      NULL);
 
+	if (gparent)
+	{
+		gtk_window_group_add_window (ephy_gui_ensure_window_group (gparent),
+					     GTK_WINDOW (dialog));
+	}
+
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
 	higgy_setup_dialog (GTK_DIALOG (dialog), GTK_STOCK_DIALOG_ERROR,
@@ -766,16 +760,20 @@ GtkNSSDialogs::SetPKCS12FilePassword(nsIInterfaceRequestor *ctx,
 	char *msg;
 
 	nsCOMPtr<nsIDOMWindow> parent = do_GetInterface (ctx);
-	GtkWidget *gparent = EphyUtils::FindGtkParent (parent);
+	GtkWindow *gparent = GTK_WINDOW (EphyUtils::FindGtkParent (parent));
 
-
-	dialog = gtk_dialog_new_with_buttons ("",
-					      GTK_WINDOW (gparent),
+	dialog = gtk_dialog_new_with_buttons ("", gparent,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_CANCEL,
 					      GTK_RESPONSE_CANCEL,
 					      NULL);
 
+	if (gparent)
+	{
+		gtk_window_group_add_window (ephy_gui_ensure_window_group (gparent),
+					     GTK_WINDOW (dialog));
+	}
+
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
 	higgy_setup_dialog (GTK_DIALOG (dialog), GTK_STOCK_DIALOG_QUESTION,
@@ -879,15 +877,20 @@ GtkNSSDialogs::GetPKCS12FilePassword(nsIInterfaceRequestor *ctx,
 	char *msg;
 
 	nsCOMPtr<nsIDOMWindow> parent = do_GetInterface (ctx);
-	GtkWidget *gparent = EphyUtils::FindGtkParent (parent);
+	GtkWindow *gparent = GTK_WINDOW (EphyUtils::FindGtkParent (parent));
 
-	dialog = gtk_dialog_new_with_buttons ("",
-					      GTK_WINDOW (gparent),
+	dialog = gtk_dialog_new_with_buttons ("", gparent,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      _("I_mport Certificate"), GTK_RESPONSE_OK,
 					      NULL);
 
+	if (gparent)
+	{
+		gtk_window_group_add_window (ephy_gui_ensure_window_group (gparent),
+					     GTK_WINDOW (dialog));
+	}
+
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
 	higgy_setup_dialog (GTK_DIALOG (dialog), GTK_STOCK_DIALOG_QUESTION,
@@ -1311,9 +1314,14 @@ GtkNSSDialogs::ViewCert(nsIInterfaceRequestor *ctx,
 				      &dialog, NULL, NULL);
 
 	nsCOMPtr<nsIDOMWindow> parent = do_GetInterface (ctx);
-	GtkWidget *gparent = EphyUtils::FindGtkParent (parent);
-	gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(gparent));
-	gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
+	GtkWindow *gparent = GTK_WINDOW (EphyUtils::FindGtkParent (parent));
+	if (gparent)
+	{
+		gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(gparent));
+		gtk_window_group_add_window (ephy_gui_ensure_window_group (GTK_WINDOW (gparent)),
+					     GTK_WINDOW (dialog));
+		gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
+	}
 
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
@@ -1465,5 +1473,3 @@ GtkNSSDialogs::ViewCert(nsIInterfaceRequestor *ctx,
 	gtk_widget_destroy (dialog);
 	return NS_OK;
 }
-
-#endif
