@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbar.c,v 1.3 2005/01/20 14:45:06 chpe Exp $
+ *  $Id: ephy-toolbar.c,v 1.7.2.1 2005/03/11 20:32:48 chpe Exp $
  */
 
 #include "config.h"
@@ -75,7 +75,7 @@ struct _EphyToolbarPrivate
 	gulong set_focus_handler;
 	gboolean show_lock;
 	gboolean lock_visible;
-	gboolean fullscreen;
+	gboolean leave_fullscreen_visible;
 	gboolean spinning;
 };
 
@@ -119,10 +119,12 @@ static void
 ephy_toolbar_update_fixed_visibility (EphyToolbar *toolbar)
 {
 	EphyToolbarPrivate *priv = toolbar->priv;
+	gboolean show;
 
-	g_object_set (priv->sep_item, "visible", priv->fullscreen, NULL);
-	g_object_set (priv->exit_button, "visible", priv->fullscreen,
-					 "sensitive", priv->fullscreen, NULL);
+	show = priv->leave_fullscreen_visible;
+	g_object_set (priv->sep_item, "visible", show, NULL);
+	g_object_set (priv->exit_button, "visible", show,
+					 "sensitive", show, NULL);
 }
 
 static void
@@ -236,7 +238,7 @@ sync_user_input_cb (EphyLocationAction *action,
 	EphyTab *tab;
 	const char *address;
 
-	LOG ("sync_user_input_cb")
+	LOG ("sync_user_input_cb");
 
 	if (priv->updating_address) return;
 
@@ -250,6 +252,13 @@ sync_user_input_cb (EphyLocationAction *action,
 	priv->updating_address = FALSE;
 }
 
+static void
+lock_clicked_cb (EphyLocationAction *action,
+		 EphyToolbar *toolbar)
+{
+	g_signal_emit (toolbar, signals[LOCK_CLICKED], 0);
+}
+
 static void
 zoom_to_level_cb (GtkAction *action,
 		  float zoom,
@@ -355,6 +364,8 @@ ephy_toolbar_set_window (EphyToolbar *toolbar,
 				  G_CALLBACK (ephy_link_open), toolbar);
 	g_signal_connect (action, "notify::address",
 			  G_CALLBACK (sync_user_input_cb), toolbar);
+	g_signal_connect (action, "lock-clicked",
+			  G_CALLBACK (lock_clicked_cb), toolbar);
 	gtk_action_group_add_action (priv->action_group, action);
 	update_location_editable (toolbar);
 	g_object_unref (action);
@@ -412,12 +423,12 @@ ephy_toolbar_set_favicon (EphyToolbar *toolbar,
 }
 
 void
-ephy_toolbar_set_fullscreen_mode (EphyToolbar *toolbar,
-				  gboolean fullscreen)
+ephy_toolbar_set_show_leave_fullscreen (EphyToolbar *toolbar,
+					gboolean show)
 {
 	EphyToolbarPrivate *priv = toolbar->priv;
 
-	priv->fullscreen = fullscreen;
+	priv->leave_fullscreen_visible = show;
 
 	ephy_toolbar_update_fixed_visibility (toolbar);
 }
@@ -437,13 +448,10 @@ ephy_toolbar_activate_location (EphyToolbar *toolbar)
 		entry = GTK_WIDGET (proxies->data);
 	}
 
-	if (entry == NULL)
-	{
-		/* happens when the user has removed the location entry from
-		 * the toolbars.
-		 */
-		return;
-	}
+	/* happens when the user has removed the location entry from
+	  * the toolbars, or when it's overflown
+	  */
+	if (entry == NULL || !GTK_WIDGET_REALIZED (entry)) return;
 
 	g_object_get (G_OBJECT (toolbar), "visible", &visible, NULL);
 	if (visible == FALSE)
